0.2 (2021-05-25)
================

Deprecations and Removals
-------------------------

- Deprecate ``--separator`` as a global option. It belongs to commands that print
  lists. ([1](https://github.com/sbidoul/manifestoo/issuers/1))


0.1 (2021-05-23)
================

First release.
